DescribeUsersResponse class

Constructors

DescribeUsersResponse({String? marker, int? totalNumberOfUsers, List<User>? users})
DescribeUsersResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
marker → String?
The marker to use when requesting the next set of results. If there are no additional results, the string is empty.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalNumberOfUsers → int?
The total number of users included in the results.
final
users → List<User>?
The users.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited