IllegalUserStateException class

Implemented types

Constructors

IllegalUserStateException({String? type, String? message})

Properties

code → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, String?>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited