InitiateDocumentVersionUploadResponse class

Properties

hashCode → int
The hash code for this object.
no setterinherited
metadata → DocumentMetadata?
The document metadata.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uploadMetadata → UploadMetadata?
The upload metadata.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited